#ifndef _SJOG_LIST_CALLBACKS_H
#define _SJOG_LIST_CALLBACKS_H 1

#include "sjog_list.h"

int sjog_list_timer_callback(gpointer * data);
int sjog_list_signal_delete_event_callback(GtkWidget * widget,
                                           GdkEvent * event, gpointer * data);
void sjog_list_row_selected_callback(GtkWidget * widget, gint row, gint col,
                                     GdkEventButton * event, gpointer * data);

/* TT - Added this function to properly move the window before it is displayed
 */
int sjog_list_signal_realize_callback(GtkWidget * widget);

#endif
